@@ -18,6 +18,7 @@
 #include "Experimental.h"
 
 #include "MemoryX.h"
+#include <utility>
 #include <vector>
 #include <wx/atomic.h>
 
@@ -29,10 +30,10 @@
 #include "../lib-src/portmidi/pm_common/portmidi.h"
 #include "../lib-src/portmidi/porttime/porttime.h"
 #include <cstring> // Allegro include fails if this header isn't included do to no memcpy
-#include "../lib-src/portsmf/allegro.h"
+#include "../lib-src/header-substitutes/allegro.h"
 
 class NoteTrack;
-using NoteTrackArray = std::vector < NoteTrack* >;
+using NoteTrackArray = std::vector < std::shared_ptr< NoteTrack > >;
 
 #endif // EXPERIMENTAL_MIDI_OUT
 
@@ -60,8 +61,8 @@ class SelectedRegion;
 class AudacityProject;
 
 class WaveTrack;
-using WaveTrackArray = std::vector < WaveTrack* >;
-using ConstWaveTrackArray = std::vector < const WaveTrack* >;
+using WaveTrackArray = std::vector < std::shared_ptr < WaveTrack > >;
+using WaveTrackConstArray = std::vector < std::shared_ptr < const WaveTrack > >;
 
 extern AUDACITY_DLL_API AudioIO *gAudioIO;
 
@@ -164,7 +165,7 @@ class AUDACITY_DLL_API AudioIO final {
     * If successful, returns a token identifying this particular stream
     * instance.  For use with IsStreamActive() below */
 
-   int StartStream(const ConstWaveTrackArray &playbackTracks, const WaveTrackArray &captureTracks,
+   int StartStream(const WaveTrackConstArray &playbackTracks, const WaveTrackArray &captureTracks,
 #ifdef EXPERIMENTAL_MIDI_OUT
                    const NoteTrackArray &midiTracks,
 #endif
@@ -637,7 +638,7 @@ private:
    ArrayOf<std::unique_ptr<RingBuffer>> mCaptureBuffers;
    WaveTrackArray      mCaptureTracks;
    ArrayOf<std::unique_ptr<RingBuffer>> mPlaybackBuffers;
-   ConstWaveTrackArray mPlaybackTracks;
+   WaveTrackConstArray mPlaybackTracks;
 
    ArrayOf<std::unique_ptr<Mixer>> mPlaybackMixers;
    volatile int        mStreamToken;
@@ -677,7 +678,7 @@ private:
    unsigned int        mNumCaptureChannels;
    unsigned int        mNumPlaybackChannels;
    sampleFormat        mCaptureFormat;
-   int                 mLostSamples;
+   unsigned long long  mLostSamples{ 0 };
    volatile bool       mAudioThreadShouldCallFillBuffersOnce;
    volatile bool       mAudioThreadFillBuffersLoopRunning;
    volatile bool       mAudioThreadFillBuffersLoopActive;
@@ -795,6 +796,21 @@ private:
       { wxAtomicInc( mRecordingException ); }
    void ClearRecordingException()
       { if (mRecordingException) wxAtomicDec( mRecordingException ); }
+
+   std::vector< std::pair<double, double> > mLostCaptureIntervals;
+   bool mDetectDropouts{ true };
+
+public:
+   // Pairs of starting time and duration
+   const std::vector< std::pair<double, double> > &LostCaptureIntervals()
+   { return mLostCaptureIntervals; }
+
+   // Used only for testing purposes in alpha builds
+   bool mSimulateRecordingErrors{ false };
+
+   // Whether to check the error code passed to audacityAudioCallback to
+   // detect more dropouts
+   bool mDetectUpstreamDropouts{ true };
 };
 
 #endif
