@@ -56,13 +56,13 @@ out.
 #include "FileFormats.h"
 #include "AudacityApp.h"
 
-// msmeyer: Define this to add debug output via printf()
+// msmeyer: Define this to add debug output via wxPrintf()
 //#define DEBUG_BLOCKFILE
 
 #ifdef DEBUG_BLOCKFILE
 #define BLOCKFILE_DEBUG_OUTPUT(op, i) \
    wxPrintf(wxT("[BlockFile %x %s] %s: %i\n"), (unsigned)this, \
-            mFileName.GetFullName().c_str(), wxT(op), i);
+            mFileName.GetFullName(), wxT(op), i);
 #else
 #define BLOCKFILE_DEBUG_OUTPUT(op, i)
 #endif
@@ -339,7 +339,6 @@ void BlockFile::FixSummary(void *data)
 
    float min, max;
    int bad;
-   int i;
 
    ComputeMinMax256(summary256, &min, &max, &bad);
 
@@ -347,7 +346,7 @@ void BlockFile::FixSummary(void *data)
       unsigned int *buffer = (unsigned int *)data;
       auto len = mSummaryInfo.totalSummaryBytes / 4;
 
-      for(i=0; i<len; i++)
+      for(unsigned int i=0; i<len; i++)
          buffer[i] = wxUINT32_SWAP_ALWAYS(buffer[i]);
 
       ComputeMinMax256(summary256, &min, &max, &bad);
@@ -357,8 +356,7 @@ void BlockFile::FixSummary(void *data)
       }
 
       // Hmmm, no better, we should swap back
-
-      for(i=0; i<len; i++)
+      for(unsigned i=0; i<len; i++)
          buffer[i] = wxUINT32_SWAP_ALWAYS(buffer[i]);
    }
 }
@@ -558,7 +556,7 @@ size_t BlockFile::CommonReadData(
       else {
          auto channels = info.channels;
          wxASSERT(channels >= 1);
-         wxASSERT(channel < channels);
+         wxASSERT((int)channel < channels);
 
          if (channels == 1 &&
              format == int16Sample &&
@@ -578,7 +576,7 @@ size_t BlockFile::CommonReadData(
             // significant bytes -- we want it in the 3 least
             // significant bytes.
             int *intPtr = (int *)data;
-            for( int i = 0; i < framesRead; i++ )
+            for( size_t i = 0; i < framesRead; i++ )
                intPtr[i] = intPtr[i] >> 8;
          }
          else if (format == int16Sample &&
@@ -590,7 +588,7 @@ size_t BlockFile::CommonReadData(
             SampleBuffer buffer(len * channels, int16Sample);
             framesRead = SFCall<sf_count_t>(
                sf_readf_short, sf.get(), (short *)buffer.ptr(), len);
-            for (int i = 0; i < framesRead; i++)
+            for (size_t i = 0; i < framesRead; i++)
                ((short *)data)[i] =
                ((short *)buffer.ptr())[(channels * i) + channel];
          }
@@ -695,7 +693,7 @@ void AliasBlockFile::WriteSummary()
       // Never silence the Log w.r.t write errors; they always count
       // as NEW errors
       wxLogError(wxT("Unable to write summary data to file %s"),
-                   mFileName.GetFullPath().c_str());
+                   mFileName.GetFullPath());
       // If we can't write, there's nothing to do.
       return;
    }
