@@ -41,7 +41,6 @@ a graph for EffectScienFilter.
 #include <wx/brush.h>
 #include <wx/dcmemory.h>
 #include <wx/intl.h>
-#include <wx/msgdlg.h>
 #include <wx/settings.h>
 #include <wx/utils.h>
 #include <wx/valgen.h>
@@ -55,6 +54,7 @@ a graph for EffectScienFilter.
 #include "../Theme.h"
 #include "../WaveTrack.h"
 #include "../widgets/valnum.h"
+#include "../widgets/ErrorDialog.h"
 
 #include "Equalization.h" // For SliderAx
 
@@ -186,7 +186,7 @@ wxString EffectScienFilter::GetSymbol()
 
 wxString EffectScienFilter::GetDescription()
 {
-   return XO("Performs IIR filtering that emulates analog filters");
+   return _("Performs IIR filtering that emulates analog filters");
 }
 
 wxString EffectScienFilter::ManualPage()
@@ -348,7 +348,7 @@ bool EffectScienFilter::Init()
          {
             if (t->GetRate() != rate)
             {
-               wxMessageBox(_("To apply a filter, all selected tracks must have the same sample rate."));
+               Effect::MessageBox(_("To apply a filter, all selected tracks must have the same sample rate."));
                return false;
             }
          }
@@ -408,18 +408,18 @@ void EffectScienFilter::PopulateOrExchange(ShuttleGui & S)
       {
          S.AddVariableText(_("+ dB"), false, wxCENTER);
          S.SetStyle(wxSL_VERTICAL | wxSL_INVERSE);
-         mdBMaxSlider = S.Id(ID_dBMax).AddSlider(wxT(""), 10, 20, 0);
+         mdBMaxSlider = S.Id(ID_dBMax).AddSlider( {}, 10, 20, 0);
 #if wxUSE_ACCESSIBILITY
          mdBMaxSlider->SetName(_("Max dB"));
-         mdBMaxSlider->SetAccessible(safenew SliderAx(mdBMaxSlider, wxString(wxT("%d ")) + _("dB")));
+         mdBMaxSlider->SetAccessible(safenew SliderAx(mdBMaxSlider, _("%d dB")));
 #endif
 
          S.SetStyle(wxSL_VERTICAL | wxSL_INVERSE);
-         mdBMinSlider = S.Id(ID_dBMin).AddSlider(wxT(""), -10, -10, -120);
+         mdBMinSlider = S.Id(ID_dBMin).AddSlider( {}, -10, -10, -120);
          S.AddVariableText(_("- dB"), false, wxCENTER);
 #if wxUSE_ACCESSIBILITY
          mdBMinSlider->SetName(_("Min dB"));
-         mdBMinSlider->SetAccessible(safenew SliderAx(mdBMinSlider, wxString(wxT("%d ")) + _("dB")));
+         mdBMinSlider->SetAccessible(safenew SliderAx(mdBMinSlider, _("%d dB")));
 #endif
       }
       S.EndVerticalLay();
@@ -483,7 +483,7 @@ void EffectScienFilter::PopulateOrExchange(ShuttleGui & S)
          vldRipple.SetRange(MIN_Passband, MAX_Passband);
          
          mRippleCtlP = S.AddVariableText(_("&Passband Ripple:"), false, wxALL | wxALIGN_RIGHT | wxALIGN_CENTER_VERTICAL);
-         mRippleCtl = S.Id(ID_Ripple).AddTextBox(wxT(""), wxT(""), 10);
+         mRippleCtl = S.Id(ID_Ripple).AddTextBox( {}, wxT(""), 10);
          mRippleCtl->SetName(_("Passband Ripple (dB)"));
          mRippleCtl->SetValidator(vldRipple);
          mRippleCtlU = S.AddVariableText(_("dB"), false, wxALL | wxALIGN_LEFT | wxALIGN_CENTER_VERTICAL);
@@ -512,7 +512,7 @@ void EffectScienFilter::PopulateOrExchange(ShuttleGui & S)
          vldStopbandRipple.SetRange(MIN_Stopband, MAX_Stopband);
          
          mStopbandRippleCtlP = S.AddVariableText(_("Minimum S&topband Attenuation:"), false, wxALL | wxALIGN_RIGHT | wxALIGN_CENTER_VERTICAL);
-         mStopbandRippleCtl = S.Id(ID_StopbandRipple).AddTextBox(wxT(""), wxT(""), 10);
+         mStopbandRippleCtl = S.Id(ID_StopbandRipple).AddTextBox( {}, wxT(""), 10);
          mStopbandRippleCtl->SetName(_("Minimum S&topband Attenuation (dB)"));
          mStopbandRippleCtl->SetValidator(vldStopbandRipple);
          mStopbandRippleCtlU = S.AddVariableText(_("dB"), false, wxALL | wxALIGN_LEFT | wxALIGN_CENTER_VERTICAL);
@@ -579,7 +579,7 @@ bool EffectScienFilter::TransferGraphLimitsFromWindow()
    if (dB != mdBMin) {
       rr = true;
       mdBMin = dB;
-      tip.Printf(wxString(wxT("%d ")) + _("dB"), (int)mdBMin);
+      tip.Printf(_("%d dB"), (int)mdBMin);
       mdBMinSlider->SetToolTip(tip);
    }
 
@@ -587,7 +587,7 @@ bool EffectScienFilter::TransferGraphLimitsFromWindow()
    if (dB != mdBMax) {
       rr = true;
       mdBMax = dB;
-      tip.Printf(wxString(wxT("%d ")) + _("dB"),(int)mdBMax);
+      tip.Printf(_("%d dB"),(int)mdBMax);
       mdBMaxSlider->SetToolTip(tip);
    }
 
