@@ -32,6 +32,7 @@
 #include "../ShuttleGui.h"
 #include "../WaveTrack.h"
 #include "../widgets/valnum.h"
+#include "../widgets/ErrorDialog.h"
 
 // Declaration of RegionList
 class RegionList : public std::list < Region > {};
@@ -116,7 +117,7 @@ wxString EffectTruncSilence::GetSymbol()
 
 wxString EffectTruncSilence::GetDescription()
 {
-   return XO("Automatically reduces the length of passages where the volume is below a specified level");
+   return _("Automatically reduces the length of passages where the volume is below a specified level");
 }
 
 wxString EffectTruncSilence::ManualPage()
@@ -288,7 +289,7 @@ bool EffectTruncSilence::ProcessIndependently()
                if (track2->GetKind() == Track::Wave &&
                   !(track2 == track || track2 == link) &&
                   track2->GetSelected()) {
-                  ::wxMessageBox(_("When truncating independently, there may only be one selected audio track in each Sync-Locked Track Group."));
+                  ::Effect::MessageBox(_("When truncating independently, there may only be one selected audio track in each Sync-Locked Track Group."));
                   return false;
                }
             }
@@ -734,7 +735,7 @@ void EffectTruncSilence::PopulateOrExchange(ShuttleGui & S)
       S.StartHorizontalLay();
       {
          // Action choices
-         mActionChoice = S.AddChoice(wxT(""), wxT(""), &actionChoices);
+         mActionChoice = S.AddChoice( {}, wxT(""), &actionChoices);
          mActionChoice->SetValidator(wxGenericValidator(&mActionIndex));
          S.SetSizeHints(-1, -1);
       }
