@@ -64,7 +64,7 @@ auto ToolBarConfiguration::FindPlace(const ToolBar *bar) const
       });
 }
 
-auto ToolBarConfiguration::FindParent(const ToolBar *bar)
+auto ToolBarConfiguration::FindPeers(const ToolBar *bar)
    -> std::pair<Forest*, Forest::iterator>
 {
    auto findTree = [=](Forest &forest){
@@ -102,6 +102,7 @@ void ToolBarConfiguration::Insert(ToolBar *bar, Position position)
 {
    if (position == UnspecifiedPosition) {
       // Add at the "end" of the layout
+      // bottommost and rightmost
       Forest *pForest = &mForest;
       while (!pForest->empty())
          pForest = &pForest->back().children;
@@ -109,13 +110,19 @@ void ToolBarConfiguration::Insert(ToolBar *bar, Position position)
       pForest->back().pBar = bar;
    }
    else {
+      // Insert at what depth?
       auto pForest = &mForest;
       if (position.rightOf) {
          const auto parent = FindPlace(position.rightOf);
          if (parent != end())
+            // Insert among children of some node
             pForest = &parent->pTree->children;
       }
+      else {
+         // Insert a new root in the top forest
+      }
 
+      // Insert at what breadth?
       const auto begin = pForest->begin();
       auto iter = begin;
       const auto end = pForest->end();
@@ -135,16 +142,22 @@ void ToolBarConfiguration::Insert(ToolBar *bar, Position position)
             iter = begin;
       }
       else
+         // No previous sibling specified, so insert as first
          adopt = (iter != end);
 
-      // Adopt the child only if the insertion point specifies that
+      // Insert as a leaf, or as an internal node?
       if (adopt && position.adopt) {
-         // Make NEW node with one child
+         // Existing child of parent become its grandchild
+
+         // TODO:  is it ever correct to adopt more than one, depending on
+         // heights?  Could an inserted tall bar adopt two short ones?
+
+         // Make NEW node
          Tree tree;
          tree.pBar = bar;
-         tree.children.push_back(Tree{});
 
          // Do adoption
+         tree.children.push_back(Tree{});
          auto &child = tree.children.back();
          child.pBar = iter->pBar;
          child.children.swap(iter->children);
@@ -153,6 +166,7 @@ void ToolBarConfiguration::Insert(ToolBar *bar, Position position)
          (*iter).swap(tree);
       }
       else
+         // Insert as a leaf
          pForest->insert(iter, Tree {})->pBar = bar;
    }
 }
@@ -166,6 +180,9 @@ void ToolBarConfiguration::InsertAtPath
    // Guarantee the existence of nodes
    for (auto ii : path) {
       Forest::size_type uu = std::max(0, ii);
+      // This may make more than one default-constructed tree, which we
+      // will fill in with some other call to InsertAtPath, or else cleanup
+      // with RemoveNulls
       pForest->resize(std::max(uu + 1, pForest->size()));
       pTree = &(*pForest)[uu];
       pForest = &pTree->children;
@@ -177,6 +194,7 @@ void ToolBarConfiguration::InsertAtPath
 
 void ToolBarConfiguration::Remove(Forest &forest, Forest::iterator iter)
 {
+   // Reparent all of the children of the deleted node
    Tree tree;
    tree.swap(*iter);
    iter = forest.erase(iter);
@@ -191,7 +209,7 @@ void ToolBarConfiguration::Remove(Forest &forest, Forest::iterator iter)
 
 void ToolBarConfiguration::Remove(const ToolBar *bar)
 {
-   auto results = FindParent(bar);
+   auto results = FindPeers(bar);
    auto pForest = results.first;
    if (pForest) {
       // Reparent all of the children of the deleted node
@@ -225,7 +243,8 @@ bool ToolBarConfiguration::IsRightmost(const ToolBar *bar) const
       // Last of all
       return true;
    if (bar->GetRect().y != iter->pTree->pBar->GetRect().y)
-      // 	
+      // Next step in preorder traversal is not rightward to a child drawn at
+      // the same height
       return true;
    return false;
 }
@@ -237,7 +256,11 @@ bool ToolBarConfiguration::Read
 {
    bool result = true;
 
-   if (pConfiguration) {
+   // Future: might remember visibility in the configuration, not forgetting
+   // positions of hidden bars.
+   gPrefs->Read( wxT("Show"), &visible, defaultVisible);
+
+   if (pConfiguration && visible) {
       int ord;
       gPrefs->Read( wxT("Order"), &ord, -1 );
       // Index was written 1-based
@@ -267,10 +290,6 @@ bool ToolBarConfiguration::Read
       }
    }
 
-   // Future: might remember visibility in the configuration, not forgetting
-   // positions of hidden bars.
-   gPrefs->Read( wxT("Show"), &visible, defaultVisible);
-
    return result;
 }
 
@@ -292,6 +311,8 @@ void ToolBarConfiguration::PostRead(Legacy &legacy)
    // against the case of obsolete preferences, perhaps
    RemoveNulls(mForest);
 
+   // Interpret what was saved in old .cfg files under "order"
+   // which specified toolbar configuration simply as a sequence, not a tree
    ToolBar *prev {};
    for (auto pBar : legacy.bars) {
       if (!pBar)
@@ -307,7 +328,9 @@ void ToolBarConfiguration::PostRead(Legacy &legacy)
 void ToolBarConfiguration::Write
    (const ToolBarConfiguration *pConfiguration, const ToolBar *bar)
 {
+   // Assume a path has been set in gPrefs suitable for bar
    if (pConfiguration) {
+      // Write comma-separated list of numbers specifying position in the tree
       wxString strPath;
       const auto cIter = pConfiguration->FindPlace(bar);
       const auto path = cIter.GetPath();
@@ -320,6 +343,9 @@ void ToolBarConfiguration::Write
       gPrefs->Write(wxT("Path"), strPath);
 
       // Remove any legacy configuration info.
+      // Note:  this causes Audacity 2.1.2 and earlier to create toolbars
+      // always in default position when reading a .cfg saved by Audacity
+      // 2.1.3 or later
       gPrefs->DeleteEntry(wxT("Order"));
    }
    gPrefs->Write( wxT("Show"), bar->IsVisible() );
@@ -376,8 +402,8 @@ void ToolDock::Undock( ToolBar *bar )
    if( mConfiguration.Contains( bar ) )
    {
       mConfiguration.Remove( bar );
-      mBars[ bar->GetId() ] = nullptr;
    }
+   mBars[ bar->GetId() ] = nullptr;
 }
 
 //
@@ -403,14 +429,15 @@ void ToolDock::Dock( ToolBar *bar, bool deflate, ToolBarConfiguration::Position
    );
 
    // Park the NEW bar in the correct berth
-   if (!mConfiguration.Contains(bar))
+   if (!mConfiguration.Contains(bar) && bar->IsVisible())
       mConfiguration.Insert( bar, position );
 
    // Inform toolbar of change
    bar->SetDocked( this, false );
 
    // Rearrange our world
-   LayoutToolBars();
+   if (bar->IsVisible())
+      LayoutToolBars();
    Updated();
 }
 
@@ -427,6 +454,7 @@ void ToolDock::LoadConfig()
    }
 }
 
+// A policy object for the skeleton routine below
 class ToolDock::LayoutVisitor
 {
 public:
@@ -450,6 +478,8 @@ public:
    }
 };
 
+// Skeleton routine common to insertion of a toolbar, and figuring out
+// width-constrained layout of toolbars
 void ToolDock::VisitLayout(LayoutVisitor &visitor,
                            ToolBarConfiguration *pWrappedConfiguration)
 {
@@ -505,7 +535,7 @@ void ToolDock::VisitLayout(LayoutVisitor &visitor,
          prevSib = sib;
          sib = ct;
       }
-      ToolBarConfiguration::Position prevPosition = { parent, prevSib };
+      auto prevPosition = ToolBarConfiguration::Position{ parent, prevSib };
 
       // Determine the size of the toolbar to fit, with advice from
       // the visitor object
@@ -682,7 +712,7 @@ void ToolDock::LayoutToolBars()
 
 // Determine the position where a NEW bar would be placed
 //
-// 'rect' will be the rectangle for the dock marker.
+// 'rect' will be the rectangle for the dock marker (black triangle)
 ToolBarConfiguration::Position
    ToolDock::PositionBar( ToolBar *t, const wxPoint & pos, wxRect & rect )
 {
@@ -891,6 +921,8 @@ void ToolDock::OnPaint( wxPaintEvent & WXUNUSED(event) )
 
       wxRect r = toolbar->GetRect();
 
+      // Draw a horizontal line under the bar extending to the right edge of
+      // the dock
       AColor::Line( dc,
                    r.GetLeft(),
                    r.GetBottom() + 1,
@@ -898,8 +930,8 @@ void ToolDock::OnPaint( wxPaintEvent & WXUNUSED(event) )
                    r.GetBottom() + 1 );
 
       // For all bars but the last...
-      // ...and for bars that aren't the last in a row, draw an
-      // horizontal gap line
+      // ...and for bars that aren't the last in a row, draw a
+      // vertical gap line
       if (!mConfiguration.IsRightmost(toolbar)) {
          AColor::Line(dc,
             r.GetRight() + 1,
