@@ -89,7 +89,6 @@ array of Ruler::Label.
 #include "../TimeTrack.h"
 #include "../TrackPanel.h"
 #include "../TrackPanelCellIterator.h"
-#include "../Menus.h"
 #include "../NumberScale.h"
 #include "../Prefs.h"
 #include "../Snap.h"
@@ -669,7 +668,7 @@ wxString Ruler::LabelString(double d, bool major)
             wxString t1, t2, format;
             t1.Printf(wxT("%d:%02d:"), secs/3600, (secs/60)%60);
             format.Printf(wxT("%%0%d.%dlf"), mDigits+3, mDigits);
-            t2.Printf(format.c_str(), fmod(d, 60.0));
+            t2.Printf(format, fmod(d, 60.0));
             s += t1 + t2;
          }
          break;
@@ -722,7 +721,7 @@ wxString Ruler::LabelString(double d, bool major)
                format.Printf(wxT("%%%d.%dlf"), mDigits+3, mDigits);
             // The casting to float is working around an issue where 59 seconds
             // would show up as 60 when using g++ (Ubuntu 4.3.3-5ubuntu4) 4.3.3.
-            t2.Printf(format.c_str(), fmod((float)d, (float)60.0));
+            t2.Printf(format, fmod((float)d, (float)60.0));
 #else
             // For d in the range of hours, d is just very slightly below the value it should 
             // have, because of using a double, which in turn yields values like 59:59:999999 
@@ -747,7 +746,7 @@ wxString Ruler::LabelString(double d, bool major)
             // doesn't round up 59.9999999 to 60.
             double multiplier = pow( 10, mDigits);
             dd = ((int)(dd * multiplier))/multiplier;
-            t2.Printf(format.c_str(), dd);
+            t2.Printf(format, dd);
 #endif
             s += t1 + t2;
          }
@@ -2097,7 +2096,8 @@ void AdornedRulerPanel::ReCreateButtons()
       const auto button =
       ToolBar::MakeButton(
          this,
-         bmpRecoloredUpSmall, bmpRecoloredDownSmall, bmpRecoloredHiliteSmall,
+         bmpRecoloredUpSmall, bmpRecoloredDownSmall, 
+         bmpRecoloredUpHiliteSmall, bmpRecoloredHiliteSmall, 
          bitmap, bitmap, bitmap,
          id, position, toggle, size
       );
@@ -2109,7 +2109,8 @@ void AdornedRulerPanel::ReCreateButtons()
    auto button = buttonMaker(OnTogglePinnedStateID, bmpPlayPointerPinned, true);
    ToolBar::MakeAlternateImages(
       *button, 1,
-      bmpRecoloredUpSmall, bmpRecoloredDownSmall, bmpRecoloredHiliteSmall,
+      bmpRecoloredUpSmall, bmpRecoloredDownSmall, 
+      bmpRecoloredUpHiliteSmall, bmpRecoloredHiliteSmall, 
       //bmpUnpinnedPlayHead, bmpUnpinnedPlayHead, bmpUnpinnedPlayHead,
       bmpPlayPointer, bmpPlayPointer, bmpPlayPointer,
       size);
@@ -2413,7 +2414,7 @@ void AdornedRulerPanel::OnMouseEvents(wxMouseEvent &evt)
          bool switchToQP = (zone == StatusChoice::EnteringQP && mQuickPlayEnabled);
          if (switchToQP && evt.LeftDown()) {
             // We can't stop scrubbing yet (see comments in Bug 1391), but we can pause it.
-            mProject->OnPause();
+            mProject->OnPause(*mProject);
             // Don't return, fall through
          }
          else if (scrubber.IsPaused())
@@ -2426,10 +2427,10 @@ void AdornedRulerPanel::OnMouseEvents(wxMouseEvent &evt)
             // Do this hack so scrubber can detect mouse drags anywhere
             evt.ResumePropagation(wxEVENT_PROPAGATE_MAX);
 
-            if (scrubber.IsScrubbing())
-               evt.Skip();
-            else
+            //if (scrubber.IsScrubbing())
                evt.Skip();
+            //else
+               //evt.Skip();
 
             // Don't do this, it slows down drag-scrub on Mac.
             // Timer updates of display elsewhere make it unnecessary.
@@ -2552,7 +2553,7 @@ void AdornedRulerPanel::HandleQPClick(wxMouseEvent &evt, wxCoord mousePosX)
    // Temporarily unlock locked play region
    if (mPlayRegionLock && evt.LeftDown()) {
       //mPlayRegionLock = true;
-      mProject->OnUnlockPlayRegion();
+      mProject->OnUnlockPlayRegion(*mProject);
    }
 
    mLeftDownClickUnsnapped = mQuickPlayPosUnsnapped;
@@ -2732,7 +2733,7 @@ void AdornedRulerPanel::HandleQPRelease(wxMouseEvent &evt)
       if (mPlayRegionLock) {
          // Restore Locked Play region
          SetPlayRegion(mOldPlayRegionStart, mOldPlayRegionEnd);
-         mProject->OnLockPlayRegion();
+         mProject->OnLockPlayRegion(*mProject);
          // and release local lock
          mPlayRegionLock = false;
       }
@@ -2843,10 +2844,10 @@ void AdornedRulerPanel::UpdateStatusBarAndTooltips(StatusChoice choice)
 // This version toggles ruler state indirectly via the scrubber
 // to ensure that all the places where the state is shown update.
 // For example buttons and menus must update.
-void AdornedRulerPanel::OnToggleScrubRulerFromMenu(wxCommandEvent& Evt)
+void AdornedRulerPanel::OnToggleScrubRulerFromMenu(wxCommandEvent&)
 {
    auto &scrubber = mProject->GetScrubber();
-   scrubber.OnToggleScrubRuler( Evt );
+   scrubber.OnToggleScrubRuler(*mProject);
 }
 
 void AdornedRulerPanel::OnToggleScrubRuler(/*wxCommandEvent&*/)
@@ -2874,9 +2875,8 @@ void AdornedRulerPanel::UpdateButtonStates()
 {
    auto common = [this]
    (AButton &button, const wxString &commandName, const wxString &label) {
-      std::vector<wxString> commands;
-      commands.push_back(label);
-      commands.push_back(commandName);
+      CommandManager::LocalizedCommandNameVector commands( 1u,
+         { label, commandName } );
       ToolBar::SetButtonToolTip(button, commands);
       button.SetLabel(button.GetToolTipText());
 
@@ -2901,7 +2901,7 @@ void AdornedRulerPanel::UpdateButtonStates()
 
 void AdornedRulerPanel::OnTogglePinnedState(wxCommandEvent & /*event*/)
 {
-   mProject->OnTogglePinnedHead();
+   mProject->OnTogglePinnedHead(*mProject);
    UpdateButtonStates();
 }
 
@@ -3040,9 +3040,9 @@ void AdornedRulerPanel::OnAutoScroll(wxCommandEvent&)
 void AdornedRulerPanel::OnLockPlayRegion(wxCommandEvent&)
 {
    if (mProject->IsPlayRegionLocked())
-      mProject->OnUnlockPlayRegion();
+      mProject->OnUnlockPlayRegion(*mProject);
    else
-      mProject->OnLockPlayRegion();
+      mProject->OnLockPlayRegion(*mProject);
 }
 
 
